function [ret,x0,str,ts,xts]=libr_sim(t,x,u,flag);
%LIBR_SIM	is the M-file description of the SIMULINK system named LIBR_SIM.
%	The block-diagram can be displayed by typing: LIBR_SIM.
%
%	SYS=LIBR_SIM(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes LIBR_SIM to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling LIBR_SIM with a FLAG of zero:
%	[SIZES]=LIBR_SIM([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[502,562,1126,965])
     open_system(sys)
end;
set_param(sys,'BackGround',0)
set_param(sys,'algorithm',     'Linear')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     'tsim')
set_param(sys,'Min step size', 'tsim/400')
set_param(sys,'Max step size', 'tsim/350')
set_param(sys,'Relative error','1e-3')
set_param(sys,'Return vars',   '')

add_block('built-in/Note',[sys,'/',['OSCILLATIONS DUES AU GRADIENT DE GRAVITE',13,'AVEC OU SANS PERTURBATION']])
set_param([sys,'/',['OSCILLATIONS DUES AU GRADIENT DE GRAVITE',13,'AVEC OU SANS PERTURBATION']],...
		'Font Name','Arial',...
		'Font Weight','bold',...
		'Font Size',18,...
		'position',[315,5,320,10])


%     Subsystem  ['Double click',13,'on this for demo.1'].

new_system([sys,'/',['Double click',13,'on this for demo.1']])
set_param([sys,'/',['Double click',13,'on this for demo.1']],'Location',[0,46,1263,1007])
set_param([sys,'/',['Double click',13,'on this for demo.1']],...
		'Mask Display','MODELE LIBRE\nAVEC OU SANS\nPERTURBATIONS',...
		'Mask Dialogue',' ')


%     Finished composite block ['Double click',13,'on this for demo.1'].

set_param([sys,'/',['Double click',13,'on this for demo.1']],...
		'ForeGround',2,...
		'BackGround',5,...
		'hide name',0,...
		'position',[190,304,400,365])

add_block('built-in/Note',[sys,'/','Mc'])
set_param([sys,'/','Mc'],...
		'position',[290,220,295,225])

add_block('built-in/Note',[sys,'/','Mp'])
set_param([sys,'/','Mp'],...
		'position',[225,150,230,155])

add_block('built-in/Gain',[sys,'/','Gain'])
set_param([sys,'/','Gain'],...
		'hide name',0,...
		'position',[150,117,185,143])

add_block('built-in/Note',[sys,'/','m'])
set_param([sys,'/','m'],...
		'position',[152,230,157,235])


%     Subsystem  'UnNamed4'.

new_system([sys,'/','UnNamed4'])
set_param([sys,'/','UnNamed4'],'Location',[4,50,648,534])

add_block('built-in/Mux',[sys,'/','UnNamed4/Mux'])
set_param([sys,'/','UnNamed4/Mux'],...
		'inputs','3',...
		'position',[150,47,180,123])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant1'])
set_param([sys,'/','UnNamed4/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,50,85,70])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant2'])
set_param([sys,'/','UnNamed4/Constant2'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,75,85,95])

add_block('built-in/Constant',[sys,'/','UnNamed4/Constant3'])
set_param([sys,'/','UnNamed4/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'position',[65,100,85,120])

add_block('built-in/Outport',[sys,'/','UnNamed4/out_1'])
set_param([sys,'/','UnNamed4/out_1'],...
		'position',[235,75,255,95])
add_line([sys,'/','UnNamed4'],[90,60;145,60])
add_line([sys,'/','UnNamed4'],[90,85;145,85])
add_line([sys,'/','UnNamed4'],[90,110;145,110])
add_line([sys,'/','UnNamed4'],[185,85;230,85])
set_param([sys,'/','UnNamed4'],...
		'Mask Display','[consigne nulle]')


%     Finished composite block 'UnNamed4'.

set_param([sys,'/','UnNamed4'],...
		'hide name',0,...
		'position',[15,218,135,292])

add_block('built-in/Sum',[sys,'/','Sum'])
set_param([sys,'/','Sum'],...
		'hide name',0,...
		'position',[235,219,270,266])


%     Subsystem  'UnNamed1'.

new_system([sys,'/','UnNamed1'])
set_param([sys,'/','UnNamed1'],'Location',[4,50,648,534])

add_block('built-in/Inport',[sys,'/','UnNamed1/in_1'])
set_param([sys,'/','UnNamed1/in_1'],...
		'position',[15,130,35,150])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace2'])
set_param([sys,'/','UnNamed1/To Workspace2'],...
		'hide name',0,...
		'mat-name','tangage',...
		'buffer','points_trace',...
		'position',[210,112,260,128])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace'])
set_param([sys,'/','UnNamed1/To Workspace'],...
		'hide name',0,...
		'mat-name','roulis',...
		'buffer','points_trace',...
		'position',[210,42,260,58])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace1'])
set_param([sys,'/','UnNamed1/To Workspace1'],...
		'hide name',0,...
		'mat-name','v_roulis',...
		'buffer','points_trace',...
		'position',[210,77,260,93])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace3'])
set_param([sys,'/','UnNamed1/To Workspace3'],...
		'hide name',0,...
		'mat-name','v_tangage',...
		'buffer','points_trace',...
		'position',[210,148,280,162])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace4'])
set_param([sys,'/','UnNamed1/To Workspace4'],...
		'hide name',0,...
		'mat-name','lacet',...
		'buffer','points_trace',...
		'position',[205,182,255,198])

add_block('built-in/To Workspace',[sys,'/','UnNamed1/To Workspace5'])
set_param([sys,'/','UnNamed1/To Workspace5'],...
		'hide name',0,...
		'mat-name','v_lacet',...
		'buffer','points_trace',...
		'position',[205,218,285,232])

add_block('built-in/Demux',[sys,'/','UnNamed1/Demux'])
set_param([sys,'/','UnNamed1/Demux'],...
		'hide name',0,...
		'outputs','6',...
		'position',[60,38,125,237])
add_line([sys,'/','UnNamed1'],[40,140;55,140])
add_line([sys,'/','UnNamed1'],[130,50;205,50])
add_line([sys,'/','UnNamed1'],[130,85;205,85])
add_line([sys,'/','UnNamed1'],[130,120;205,120])
add_line([sys,'/','UnNamed1'],[130,155;205,155])
add_line([sys,'/','UnNamed1'],[130,190;200,190])
add_line([sys,'/','UnNamed1'],[130,225;200,225])
set_param([sys,'/','UnNamed1'],...
		'Mask Display','Sortie\nsystme\n(angles et\nvitesses angulaires)')


%     Finished composite block 'UnNamed1'.

set_param([sys,'/','UnNamed1'],...
		'ForeGround',3,...
		'hide name',0,...
		'position',[490,211,610,279])


%     Subsystem  'Perturbation'.

new_system([sys,'/','Perturbation'])
set_param([sys,'/','Perturbation'],'Location',[4,50,260,231])
open_system([sys,'/','Perturbation'])

add_block('built-in/Mux',[sys,'/','Perturbation/Mux'])
set_param([sys,'/','Perturbation/Mux'],...
		'inputs','3',...
		'position',[150,47,180,123])

add_block('built-in/Constant',[sys,'/','Perturbation/Constant1'])
set_param([sys,'/','Perturbation/Constant1'],...
		'hide name',0,...
		'Value','0',...
		'position',[40,50,85,70])

add_block('built-in/Constant',[sys,'/','Perturbation/Constant2'])
set_param([sys,'/','Perturbation/Constant2'],...
		'hide name',0,...
		'Value','8e-5',...
		'position',[40,75,85,95])

add_block('built-in/Constant',[sys,'/','Perturbation/Constant3'])
set_param([sys,'/','Perturbation/Constant3'],...
		'hide name',0,...
		'Value','0',...
		'position',[40,100,85,120])

add_block('built-in/Outport',[sys,'/','Perturbation/out_1'])
set_param([sys,'/','Perturbation/out_1'],...
		'position',[235,75,255,95])
add_line([sys,'/','Perturbation'],[90,60;145,60])
add_line([sys,'/','Perturbation'],[90,85;145,85])
add_line([sys,'/','Perturbation'],[90,110;145,110])
add_line([sys,'/','Perturbation'],[185,85;230,85])
set_param([sys,'/','Perturbation'],...
		'Mask Display','Couples\nperturbateurs Mp')


%     Finished composite block 'Perturbation'.

set_param([sys,'/','Perturbation'],...
		'ForeGround',2,...
		'position',[25,105,125,155])

add_block('built-in/To Workspace',[sys,'/','To Workspace'])
set_param([sys,'/','To Workspace'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'mat-name','temps',...
		'buffer','points_trace',...
		'position',[485,127,535,143])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'ForeGround',3,...
		'BackGround',6,...
		'hide name',0,...
		'position',[405,125,425,145])

add_block('built-in/State-Space',[sys,'/','State-space'])
set_param([sys,'/','State-space'],...
		'ForeGround',1,...
		'BackGround',2,...
		'hide name',0,...
		'A','Asat',...
		'B','Bsat',...
		'C','eye(size(Asat))',...
		'D','zeros(size(Bsat))',...
		'X0','[-0.1 0;0.2 0;-0.1 0]''')
set_param([sys,'/','State-space'],...
		'Mask Display','MODELE\nSATELLITE',...
		'position',[330,218,445,272])
add_line(sys,[190,130;210,130;210,230;230,230])
add_line(sys,[140,255;230,255])
add_line(sys,[430,135;480,135])
add_line(sys,[130,130;145,130])
add_line(sys,[450,245;485,245])
add_line(sys,[275,245;325,245])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
